<!--巡检计划-->
<template>
  <div class="border">
    <div class="bbsl-common-page">
      <template v-if="componentName === 'table'">
        <div class="bbsl-table-search">
          <el-form v-model="queryParams" label-width="auto">
            <el-row :gutter="10">
              <el-col :span="5">
                <el-form-item label="维护设备名称">
                  <el-input v-model="queryParams['plan_Name_']" :clearable="true" placeholder="请输入巡查计划名称" />
                </el-form-item>
              </el-col>
              <el-col :span="4">
                <el-button icon="el-icon-search" type="primary" @click="handleSearch">
                  搜索
                </el-button>
                <el-button icon="el-icon-refresh" @click="handleReset">
                  重置
                </el-button>
              </el-col>
            </el-row>
          </el-form>
        </div>
        <div ref="contentPanel" class="bbsl-table-content">
          <el-table ref="multipleSelection" v-loading="loading" :cell-style="{ 'text-align': 'center' }"
                    :data="tableData"
                    :header-cell-style="{ 'text-align': 'center' }"
                    :max-height="tableMaxHeight" :style="{ width: '100%' }" border
                    row-key="id" size="mini"
                    @selection-change="handleSelectionChange" @sort-change="sortChange"
          >
            <!--           @row-dblclick="row => openPage('isShowAddModify', row)" -->
            <!--            <el-table-column align="center" reserve-selection type="selection" width="55"></el-table-column>-->
            <el-table-column align="center" label="序号" type="index" width="70">
            </el-table-column>
            <el-table-column align="center" label="维护设备名称" min-width="150" prop="planName"
                             show-overflow-tooltip />
            <el-table-column align="center" label="维护时间" min-width="150" prop="planContent" show-overflow-tooltip />

            <!--            <el-table-column :formatter="({ planType }) => dictionaryEscape(inspectionTypeOpt, planType + '')"-->
            <!--                             align="center" label="维护人员" min-width="100" prop="planType"-->
            <!--                             show-overflow-tooltip />-->
            <el-table-column align="center" label="维护人员" min-width="100" prop="planType"
                             show-overflow-tooltip />
            <el-table-column align="center" label="维护单位" min-width="100" prop="planStartDate"
                             show-overflow-tooltip />
            <el-table-column align="center" label="联系方式" min-width="100" prop="planEndDate"
                             show-overflow-tooltip />
          </el-table>
          <el-pagination ref="paginationPanel" :current-page="queryParams.page" :page-size="queryParams.pageSize"
                         :page-sizes="[20, 30, 40, 50]"
                         :total="queryParams.total" align="right"
                         background
                         class="bbsl-pagination" layout="total, sizes, prev, pager, next, jumper"
                         @size-change="handleSizeChange" @current-change="handleCurrentChange"></el-pagination>
        </div>
      </template>


    </div>
    <div class="topList">
      <div
        style="
                            display: flex;
                            width: 100%;
                            justify-content: space-between;
                        "
      >
        <el-tabs style="width: 70%" value="非智能设备">
          <el-tab-pane label="非智能设备" name="非智能设备">
                                <span slot="label">
                                    <img
                                      class="tab-img"
                                      src="@/assets/img/fznxb.png"
                                    />
                                    <span class="tab-label active"
                                    >设备维护分析</span
                                    >
                                </span>
          </el-tab-pane>
        </el-tabs>
        <div class="search-cont">
          日期：
          <el-date-picker
            v-model="startYear"
            :clearable="false"
            :editable="false"
            end-placeholder="结束日期"
            range-separator="至"
            start-placeholder="开始日期"
            type="daterange"
            value-format="yyyy-MM-dd"
            @change="getChartData"
          >
          </el-date-picker>
        </div>
      </div>
      <div class="current-region">
        <div id="Bar" style="width: 100%; height: 100%"></div>
      </div>
    </div>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils'
import {dictionaryEscape} from '@/utils/dictionary'
import * as echarts from 'echarts'

export default {
  name: 'EquipmentInspectionPlan',
  components: {},
  // 日常巡检
  mixins: [TableMixin],
  data() {
    return {
      isShowAddModify: false,
      isShowDetailModify: false,
      tableData: [
        {
          id: 1,
          planName: '低洼积水监测设备',
          planContent: '9:00-11:00',
          planType: '张小勇',
          planStartDate: '设备管理部',
          planEndDate: '13800138001'
        },
        {
          id: 2,
          planName: '危险气体监测设备',
          planContent: '14:00-18:00',
          planType: '李温',
          planStartDate: '设备管理部',
          planEndDate: '13898745657'
        }
      ],
      total: 2,//总条数
      equipmentData: [
        {areaId: '1', areaName: '低洼积水监测设备', normal: 28, failure: 5},
        {areaId: '2', areaName: '危险气体监测设备', normal: 35, failure: 2},
        {areaId: '3', areaName: '标识牌倾斜监测设备', normal: 42, failure: 3},
        {areaId: '4', areaName: '防爆升降柱设备', normal: 19, failure: 7},
        {areaId: '5', areaName: '蓝牙信标', normal: 30, failure: 4},
        {areaId: '6', areaName: '移动执法记录仪', normal: 25, failure: 6},
        {areaId: '7', areaName: '杆件', normal: 38, failure: 1},
        {areaId: '8', areaName: '栏杆', normal: 22, failure: 3},
        {areaId: '9', areaName: '自动空气开关', normal: 45, failure: 2},
        {areaId: '10', areaName: '低压配电柜', normal: 33, failure: 5}
      ],
      queryParams: {
        page: 1,
        pageSize: 20,
        total: 0,
        'plan_Name_': '' // 巡检计划名称

      },
      sorter: [],
      inspectionTypeOpt: dictUtils.getDictItemsFromCache('xjlx') || [],
      rowInfo: {},
      componentName: 'table'
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    computedQuery() {
      const querys = [
        {operation: 'LIKE', property: 'plan_Name_'},
        {operation: 'EQUAL', property: 'planStartDate'},
        {operation: 'EQUAL', property: 'plan_End_Date_'},
        {operation: 'EQUAL', property: 'plan_Type_'}
      ]
      const {pageSize, page, ...item} = this.queryParams
      return {
        pageBean: {pageSize, page},
        querys: querys.flatMap(i => {
          /*
          * 取value值优先级：querys > queryParams
          * 方便后续有些参数默认值为一个固定的默认值，并且这个默认值不为空，也不会显示到页面上
          * */
          const value = i.value ?? item[i.property] ?? ''
          if (value === '') return []
          if (Array.isArray(value) && !value.length) return []
          return {group: 'main', relation: 'AND', ...i, value}
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  created() {
    this.areaStatusList()
  },
  methods: {
    dictionaryEscape,
    // 获取list -暂时tableData利用假数据
    // async loadData() {
    //   this.loading = true
    //   const {rows, total} = await tableData(this.computedQuery)
    //   this.tableData = rows
    //   this.queryParams.total = total
    //   this.loading = false
    // },

    // 顶部搜索
    handleSearch() {
      this.loadData()
    },

    // 重置
    handleReset() {
      this.queryParams = this.$options.data().queryParams
      this.loadData()
    },

    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = 1
      this.queryParams.page = page
      this.loadData()
    },

    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.page = 1
      this.queryParams.pageSize = pageSize
      this.loadData()
    },

    // 排序切换
    sortChange({prop: property, order}) {
      let direction = ''
      switch (order) {
        case 'ascending':
          direction = 'ASC'
          break
        case 'descending':
          direction = 'DESC'
          break
      }
      this.sorter.forEach(i => {
        if (i.property !== property) return i.direction = ''
        i.direction = direction
      })
      this.loadData()
    },

    // 打开功能页面
    openPage(dialog, rowInfo = {}) {
      if (rowInfo.planStatus) {
        this.componentName = 'isShowDetailModify'
      } else {
        this.componentName = dialog
      }
      this.rowInfo = rowInfo // 保存点击行信息
    },

    // 关闭功能页面
    closePage(args) {
      switch (args) {
        case 'modify':
          this.queryParams.page = 1
          break
        case 'add':
          break
      }
      this.loadData()
      this.componentName = 'table'
      this.rowInfo = {}
    },
    //设备分析
    areaStatusList() {
      const formData = new FormData()
      formData.append('areaId', this.areaId ? this.areaId : '')
      formData.append('fullId', this.fullId ? this.fullId : '')
      const config = {
        headers: {
          'Content-Type': 'multipart/form-data'
        }
      }
      this.$http
        .post(
          window.context.portal + `/homepage/v1/areaStatusAnalyze`,
          formData,
          config
        )
        .then((res) => {
          if (res.data.state) {
            // this.equipmentData = res.data.value
            this.$nextTick(() => {
              this.equipmentInit()
            })
          }
        })
    },
    // 设备分析echarts
    // equipmentInit() {
    //   let myChart = echarts.init(document.getElementById('Bar'))
    //   // 指定图表的配置项和数据
    //   let AData = []
    //   let BData = []
    //   // let CData = []
    //   this.equipmentData.forEach((e) => {
    //     AData.push({
    //       value: e.normal,
    //       extra: {
    //         param: e.areaId
    //       }
    //     })
    //     BData.push({
    //       value: e.failure,
    //       extra: {
    //         param: e.areaId
    //       }
    //     })
    //     // CData.push({
    //     //   value: e.alarm,
    //     //   extra: {
    //     //     param: e.areaId
    //     //   }
    //     // })
    //   })
    //   let option = {
    //     toolbox: {
    //       feature: {
    //         restore: {
    //           show: true,
    //           title: '返回'
    //         }
    //       },
    //       iconStyle: {
    //         borderColor: '#000'
    //       }
    //     },
    //     // title: {
    //     // 	text: '全校人数汇总',
    //     // 	left: 'center'
    //     // },
    //     tooltip: {
    //       trigger: 'axis',
    //       axisPointer: {
    //         type: 'shadow'
    //       }
    //     },
    //     legend: {},
    //     grid: {
    //       left: 50,
    //       right: 20,
    //       bottom: '10%'
    //     },
    //     xAxis: {
    //       data: this.equipmentData.map((a) => a.areaName)
    //     },
    //     yAxis: {},
    //     series: [
    //       {
    //         // color: '#1890ff',
    //         type: 'bar',
    //         name: '日常维护数',
    //         data: AData,
    //         barWidth: 25,
    //         showBackground: true,
    //         label: {
    //           show: true,
    //           fontSize: 13,
    //           color: '#000',
    //           position: 'top',
    //           // 配置自定义参数
    //           extra: {
    //             customParam: '这里是自定义参数'
    //           }
    //         },
    //         itemStyle: {
    //           normal: {
    //             color: new echarts.graphic.LinearGradient(
    //               0,
    //               0,
    //               0,
    //               1,
    //               [
    //                 {
    //                   offset: 0,
    //                   color: '#01D1FF'
    //                 },
    //                 {
    //                   offset: 1,
    //                   color: '#1890ff'
    //                 }
    //               ]
    //             )
    //           }
    //         }
    //       },
    //       {
    //         color: '#ff8000',
    //         type: 'bar',
    //         name: '故障维护数',
    //         barWidth: 25,
    //         showBackground: true,
    //         data: BData,
    //         label: {
    //           show: true,
    //           fontSize: 13,
    //           color: '#000',
    //           position: 'top',
    //           // 配置自定义参数
    //           extra: {
    //             customParam: '这里是自定义参数'
    //           }
    //         },
    //         itemStyle: {
    //           normal: {
    //             color: new echarts.graphic.LinearGradient(
    //               0,
    //               0,
    //               0,
    //               1,
    //               [
    //                 {
    //                   offset: 0,
    //                   color: '#FFBD7A'
    //                 },
    //                 {
    //                   offset: 1,
    //                   color: '#ff8000'
    //                 }
    //               ]
    //             )
    //           }
    //         }
    //       }
    //       // {
    //       //   color: '#f9c700',
    //       //   type: 'bar',
    //       //   name: '报警数',
    //       //   barWidth: 25,
    //       //   data: CData,
    //       //   showBackground: true,
    //       //   label: {
    //       //     show: true,
    //       //     fontSize: 13,
    //       //     color: '#000',
    //       //     position: 'top',
    //       //     extra: {
    //       //       customParam: '这里是自定义参数'
    //       //     }
    //       //   },
    //       //   itemStyle: {
    //       //     normal: {
    //       //       color: new echarts.graphic.LinearGradient(
    //       //         0,
    //       //         0,
    //       //         0,
    //       //         1,
    //       //         [
    //       //           {
    //       //             offset: 0,
    //       //             color: '#FFE375'
    //       //           },
    //       //           {
    //       //             offset: 1,
    //       //             color: '#f9c700'
    //       //           }
    //       //         ]
    //       //       )
    //       //     }
    //       //   }
    //       // }
    //     ]
    //   }
    //   option.xAxis.data = this.equipmentData.map((a) => a.areaName)
    //   myChart.setOption(option)
    //   // 点击柱状触发事件（点击事件，点击下钻查询年级所属的班级数据） 如不需要下钻查询可不写
    //   myChart.on('click', (params) => {
    //     let areaId = params.data.extra.param
    //     if (areaId) {
    //       const formData = new FormData()
    //       formData.append('areaId', areaId ? areaId : '')
    //       formData.append('fullId', this.fullId ? this.fullId : '')
    //       const config = {
    //         headers: {
    //           'Content-Type': 'multipart/form-data'
    //         }
    //       }
    //       this.$http
    //         .post(
    //           window.context.portal +
    //           `/homepage/v1/areaStatusAnalyze`,
    //           formData,
    //           config
    //         )
    //         .then((res) => {
    //           if (res.data.state) {
    //             let AData = []
    //             let BData = []
    //             let CData = []
    //             this.equipmentData = res.data.value
    //             res.data.value.forEach((e) => {
    //               AData.push({
    //                 value: e.normal,
    //                 extra: {
    //                   param: e.areaId
    //                 }
    //               })
    //               BData.push({
    //                 value: e.failure,
    //                 extra: {
    //                   param: e.areaId
    //                 }
    //               })
    //               CData.push({
    //                 value: e.alarm,
    //                 extra: {
    //                   param: e.areaId
    //                 }
    //               })
    //             })
    //             option.series = [
    //               {
    //                 color: '#1890ff',
    //                 type: 'bar',
    //                 name: '正常数',
    //                 data: AData
    //               },
    //               {
    //                 color: '#ff8000',
    //                 type: 'bar',
    //                 name: '故障数',
    //                 data: BData
    //               },
    //               {
    //                 color: '#f9c700',
    //                 type: 'bar',
    //                 name: '报警数',
    //                 data: CData
    //               }
    //             ]
    //             option.xAxis.data = this.equipmentData.map(
    //               (a) => a.areaName
    //             )
    //             myChart.setOption(option)
    //           }
    //         })
    //     }
    //   })
    // }
    equipmentInit() {
      let myChart = echarts.init(document.getElementById('Bar'))

      // 准备数据
      let AData = this.equipmentData.map(e => ({
        value: e.normal,
        extra: {param: e.areaId}
      }))

      let BData = this.equipmentData.map(e => ({
        value: e.failure,
        extra: {param: e.areaId}
      }))

      let option = {
        toolbox: {
          feature: {
            restore: {show: true, title: '返回'}
          },
          iconStyle: {
            borderColor: '#000'
          }
        },
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow'
          },
          formatter: function(params) {
            let result = params[0].name + '<br/>'
            params.forEach(item => {
              result += item.marker + ' ' + item.seriesName + ': ' + item.value + '<br/>'
            })
            return result
          }
        },
        legend: {
          data: ['日常维护数', '故障维护数'],
          top: 0
        },
        grid: {
          left: 50,
          right: 20,
          bottom: '15%',
          top: '10%',
          containLabel: true
        },
        xAxis: {
          type: 'category',
          data: this.equipmentData.map(a => a.areaName),
          axisLabel: {
            interval: 0
            // rotate: 30 // 如果标签太长可以旋转30度
          }
        },
        yAxis: {
          type: 'value',
          name: '数量',
          nameTextStyle: {
            padding: [0, 0, 0, 30]
          }
        },
        series: [
          {
            type: 'bar',
            name: '日常维护数',
            data: AData,
            barWidth: 25,
            showBackground: true,
            label: {
              show: true,
              position: 'top',
              color: '#000',
              fontSize: 12
            },
            itemStyle: {
              color: new echarts.graphic.LinearGradient(
                0, 0, 0, 1,
                [
                  {offset: 0, color: '#01D1FF'},
                  {offset: 1, color: '#1890ff'}
                ]
              )
            }
          },
          {
            type: 'bar',
            name: '故障维护数',
            data: BData,
            barWidth: 25,
            showBackground: true,
            label: {
              show: true,
              position: 'top',
              color: '#000',
              fontSize: 12
            },
            itemStyle: {
              color: new echarts.graphic.LinearGradient(
                0, 0, 0, 1,
                [
                  {offset: 0, color: '#FFBD7A'},
                  {offset: 1, color: '#ff8000'}
                ]
              )
            }
          }
        ]
      }

      myChart.setOption(option)

      // 窗口大小变化时重绘图表
      window.addEventListener('resize', function() {
        myChart.resize()
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.border {
  width: 100%;
  height: 100%;
  background-color: #e8ebf2;

  .bbsl-common-page {
    height: 50% !important;
    border-radius: 10px;
  }
}

.type-tag {
  margin: 0 2px;
}

::v-deep .el-link {
  span {
    font-size: 14PX;
  }
}

.tab-img {
  width: 16px;
  height: 16px;
  vertical-align: middle;
  margin-right: 10px;
}

.tab-label {
  color: #666;
  font-size: 16px;
}

.tab-label.active {
  color: #0080ff;
  font-weight: bold;
}

/*去掉tabs底部的下划线*/
::v-deep .el-tabs__nav-wrap::after {
  position: static !important;
}

::v-deep .el-tabs__active-bar {
  height: 4px;
  border-radius: 2px;
  background: linear-gradient(0deg, #0080ff, #b2d9ff);
  box-shadow: 0px 1px 5px 0px rgba(83, 136, 255, 0.4);
}

.bbsl-table-search {
  //border-radius: 10px 10px 0 0;
}

.bbsl-table-content {
  margin-top: 0 !important;
  box-shadow: none;
  border-radius: 0 0 10px 10px;
}

.topList {
  position: relative;
  height: calc(60% - 100px);
  background-color: #fff;
  border-radius: 10px;
  padding: 10px;
  box-sizing: border-box;
  margin-bottom: 10px;

  .current-region {
    width: 100%;
    height: 90%;
  }
}

.search-cont {
  position: absolute;
  right: 15px;
  top: 10px;
}
</style>
